pub struct AuthProviderChain { /* private fields */ }Expand description
Tries providers in order until one succeeds.
Implementations
Sourceimpl AuthProviderChain
impl AuthProviderChain
Sourcepub fn with_provider(self, provider: Arc<dyn AuthProvider>) -> Self
pub fn with_provider(self, provider: Arc<dyn AuthProvider>) -> Self
Add a provider to the end of the chain.
Sourcepub fn add(&mut self, provider: Arc<dyn AuthProvider>)
pub fn add(&mut self, provider: Arc<dyn AuthProvider>)
Add a provider to the end of the chain (mutable).